pub struct BufferedReader<R: Read> { /* private fields */ }
Similar to std::io::BufRead, but more performant.

There is no simple way to wrap a standard BufRead such that it can compute checksums on consume. This is really something that needs a less restrictive interface. Apart from enabling checksum computations, this buffered reader has some convenience functions.

Implementations

Wrap the reader in a new buffered reader.

Destroys the buffered reader, returning the wrapped reader.

Anything in the buffer will be lost.